Crate open_redact_pdf

Crate open_redact_pdf 

Public Rust API for Open Redact PDF.

This crate is the stable facade over the internal parser, graphics, text, target normalization, redaction, and writer crates.

Structs

FillColor
PageSize
Normalized page size in PDF user-space units.
PageText
Extracted text content and geometry for a single page.
PdfDocument
Parsed PDF document handle used for inspection, redaction, and save.
RedactionPlan
TextMatch

Enums

PdfError
RedactionMode
Controls the visual output of text redaction.
RedactionTarget