Public Rust API for Open Redact PDF.
This crate is the stable facade over the internal parser, graphics, text, target normalization, redaction, and writer crates.
Structs
- Fill
Color - Page
Size - Normalized page size in PDF user-space units.
- Page
Text - Extracted text content and geometry for a single page.
- PdfDocument
- Parsed PDF document handle used for inspection, redaction, and save.
- Redaction
Plan - Text
Match
Enums
- PdfError
- Redaction
Mode - Controls the visual output of text redaction.
- Redaction
Target